/* THIS FILE IS AUTOMATICALLY GENERATED - DO NOT EDIT */

#define VBE_DISPI_TOTAL_VIDEO_MEMORY_MB 16

static ModeInfoListItem mode_info_list[]=
{
{ 0x0100, /* 640x400x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 640,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 400,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 4,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 64,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 640,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0101, /* 640x480x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 640,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 480,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 5,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 53,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 640,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0102, /* 800x600x4 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_TTY_BIOS_SUPPORT | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 100,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 4,
/*Bit8u  BitsPerPixel*/ 4,
/*Bit8u  NumberOfBanks*/ 1,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PLANAR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 68,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ 0,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 100,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0103, /* 800x600x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 800,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 8,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 33,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 800,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0104, /* 1024x768x4 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_TTY_BIOS_SUPPORT | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 128,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 4,
/*Bit8u  BitsPerPixel*/ 4,
/*Bit8u  NumberOfBanks*/ 2,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PLANAR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 41,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ 0,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 128,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0105, /* 1024x768x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1024,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 12,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 20,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1024,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0106, /* 1280x1024x4 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_TTY_BIOS_SUPPORT | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 160,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 4,
/*Bit8u  BitsPerPixel*/ 4,
/*Bit8u  NumberOfBanks*/ 3,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PLANAR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 24,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ 0,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 160,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0107, /* 1280x1024x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1280,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 20,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 11,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1280,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x010d, /* 320x200x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 640,
/*Bit16u XResolution*/ 320,
/*Bit16u YResolution*/ 200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 2,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 130,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 640,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x010e, /* 320x200x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 640,
/*Bit16u XResolution*/ 320,
/*Bit16u YResolution*/ 200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 2,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 130,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 640,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x010f, /* 320x200x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 960,
/*Bit16u XResolution*/ 320,
/*Bit16u YResolution*/ 200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 3,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 86,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 960,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0110, /* 640x480x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1280,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 480,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 10,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 26,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1280,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0111, /* 640x480x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1280,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 480,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 10,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 26,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1280,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0112, /* 640x480x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1920,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 480,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 15,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 17,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1920,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0113, /* 800x600x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1600,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 15,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 16,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1600,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0114, /* 800x600x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1600,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 15,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 16,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1600,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0115, /* 800x600x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2400,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 22,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 10,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2400,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0116, /* 1024x768x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2048,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 24,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 9,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2048,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0117, /* 1024x768x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2048,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 24,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 9,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2048,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0118, /* 1024x768x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3072,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 36,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 6,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3072,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0119, /* 1280x1024x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 40,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 5,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011a, /* 1280x1024x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 40,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 5,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011b, /* 1280x1024x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 60,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011c, /* 1600x1200x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1600,
/*Bit16u XResolution*/ 1600,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 30,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1600,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011d, /* 1600x1200x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3200,
/*Bit16u XResolution*/ 1600,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 59,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3200,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011e, /* 1600x1200x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3200,
/*Bit16u XResolution*/ 1600,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 59,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3200,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x011f, /* 1600x1200x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 4800,
/*Bit16u XResolution*/ 1600,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 88,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 4800,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0140, /* 320x200x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1280,
/*Bit16u XResolution*/ 320,
/*Bit16u YResolution*/ 200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 4,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 64,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1280,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0141, /* 640x400x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 400,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 16,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 15,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0142, /* 640x480x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 640,
/*Bit16u YResolution*/ 480,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 19,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 12,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0143, /* 800x600x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3200,
/*Bit16u XResolution*/ 800,
/*Bit16u YResolution*/ 600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 30,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3200,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0144, /* 1024x768x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 4096,
/*Bit16u XResolution*/ 1024,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 48,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 4,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 4096,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0145, /* 1280x1024x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 1024,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 80,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0146, /* 320x200x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 320,
/*Bit16u XResolution*/ 320,
/*Bit16u YResolution*/ 200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 1,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 261,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 320,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0147, /* 1600x1200x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 6400,
/*Bit16u XResolution*/ 1600,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 118,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 6400,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0148, /* 1152x864x8 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 1152,
/*Bit16u XResolution*/ 1152,
/*Bit16u YResolution*/ 864,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 8,
/*Bit8u  NumberOfBanks*/ 16,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_PACKED_PIXEL,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 15,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 0,
/*Bit8u  RedFieldPosition*/ 0,
/*Bit8u  GreenMaskSize*/ 0,
/*Bit8u  GreenFieldPosition*/ 0,
/*Bit8u  BlueMaskSize*/ 0,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 1152,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 0,
/*Bit8u  LinRedFieldPosition*/ 0,
/*Bit8u  LinGreenMaskSize*/ 0,
/*Bit8u  LinGreenFieldPosition*/ 0,
/*Bit8u  LinBlueMaskSize*/ 0,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0149, /* 1152x864x15 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2304,
/*Bit16u XResolution*/ 1152,
/*Bit16u YResolution*/ 864,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 15,
/*Bit8u  NumberOfBanks*/ 31,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 10,
/*Bit8u  GreenMaskSize*/ 5,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 1,
/*Bit8u  RsvdFieldPosition*/ 15,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2304,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 10,
/*Bit8u  LinGreenMaskSize*/ 5,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 1,
/*Bit8u  LinRsvdFieldPosition*/ 15,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x014a, /* 1152x864x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2304,
/*Bit16u XResolution*/ 1152,
/*Bit16u YResolution*/ 864,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 31,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2304,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x014b, /* 1152x864x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3456,
/*Bit16u XResolution*/ 1152,
/*Bit16u YResolution*/ 864,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 46,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 4,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3456,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x014c, /* 1152x864x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 4608,
/*Bit16u XResolution*/ 1152,
/*Bit16u YResolution*/ 864,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 61,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 4608,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0175, /* 1280x768x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 30,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0176, /* 1280x768x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 45,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 4,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0177, /* 1280x768x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 768,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 60,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0178, /* 1280x800x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 800,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 32,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 7,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0179, /* 1280x800x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 800,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 47,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 4,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017a, /* 1280x800x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 800,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 63,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017b, /* 1280x960x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 960,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 38,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 5,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017c, /* 1280x960x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 960,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 57,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017d, /* 1280x960x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 960,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 75,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017e, /* 1440x900x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2880,
/*Bit16u XResolution*/ 1440,
/*Bit16u YResolution*/ 900,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 40,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 5,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2880,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x017f, /* 1440x900x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 4320,
/*Bit16u XResolution*/ 1440,
/*Bit16u YResolution*/ 900,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 60,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 4320,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0180, /* 1440x900x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5760,
/*Bit16u XResolution*/ 1440,
/*Bit16u YResolution*/ 900,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 80,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5760,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0181, /* 1400x1050x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2800,
/*Bit16u XResolution*/ 1400,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 45,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 4,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2800,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0182, /* 1400x1050x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 4200,
/*Bit16u XResolution*/ 1400,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 68,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 4200,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0183, /* 1400x1050x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5600,
/*Bit16u XResolution*/ 1400,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 90,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5600,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0184, /* 1680x1050x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3360,
/*Bit16u XResolution*/ 1680,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 54,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3360,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0185, /* 1680x1050x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5040,
/*Bit16u XResolution*/ 1680,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 81,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5040,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0186, /* 1680x1050x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 6720,
/*Bit16u XResolution*/ 1680,
/*Bit16u YResolution*/ 1050,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 108,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 6720,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0187, /* 1920x1200x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 71,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 2,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0188, /* 1920x1200x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5760,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 106,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5760,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0189, /* 1920x1200x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 7680,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1200,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 141,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 0,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 7680,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018a, /* 2560x1600x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 2560,
/*Bit16u YResolution*/ 1600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 125,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018b, /* 2560x1600x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 7680,
/*Bit16u XResolution*/ 2560,
/*Bit16u YResolution*/ 1600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 188,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 0,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 7680,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018c, /* 2560x1600x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 10240,
/*Bit16u XResolution*/ 2560,
/*Bit16u YResolution*/ 1600,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 250,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 0,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 10240,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018d, /* 1280x720x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 2560,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 720,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 29,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 8,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 2560,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018e, /* 1280x720x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 720,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 43,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 5,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x018f, /* 1280x720x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5120,
/*Bit16u XResolution*/ 1280,
/*Bit16u YResolution*/ 720,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 57,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5120,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0190, /* 1920x1080x16 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 3840,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1080,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 16,
/*Bit8u  NumberOfBanks*/ 64,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 3,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 5,
/*Bit8u  RedFieldPosition*/ 11,
/*Bit8u  GreenMaskSize*/ 6,
/*Bit8u  GreenFieldPosition*/ 5,
/*Bit8u  BlueMaskSize*/ 5,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 3840,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 5,
/*Bit8u  LinRedFieldPosition*/ 11,
/*Bit8u  LinGreenMaskSize*/ 6,
/*Bit8u  LinGreenFieldPosition*/ 5,
/*Bit8u  LinBlueMaskSize*/ 5,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0191, /* 1920x1080x24 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 5760,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1080,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 24,
/*Bit8u  NumberOfBanks*/ 95,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 0,
/*Bit8u  RsvdFieldPosition*/ 0,
/*Bit8u  DirectColorModeInfo*/ 0,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 5760,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 0,
/*Bit8u  LinRsvdFieldPosition*/ 0,
/*Bit32u MaxPixelClock*/ 0,
} },
{ 0x0192, /* 1920x1080x32 */
{ /*Bit16u ModeAttributes*/ VBE_MODE_ATTRIBUTE_SUPPORTED | VBE_MODE_ATTRIBUTE_EXTENDED_INFORMATION_AVAILABLE | VBE_MODE_ATTRIBUTE_COLOR_MODE | VBE_MODE_ATTRIBUTE_LINEAR_FRAME_BUFFER_MODE | VBE_MODE_ATTRIBUTE_GRAPHICS_MODE,
/*Bit8u  WinAAttributes*/ VBE_WINDOW_ATTRIBUTE_RELOCATABLE | VBE_WINDOW_ATTRIBUTE_READABLE | VBE_WINDOW_ATTRIBUTE_WRITEABLE,
/*Bit8u  WinBAttributes*/ 0,
/*Bit16u WinGranularity*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinSize*/ VBE_DISPI_BANK_SIZE_KB,
/*Bit16u WinASegment*/ VGAMEM_GRAPH,
/*Bit16u WinBSegment*/ 0x0000,
/*Bit32u WinFuncPtr*/ 0,
/*Bit16u BytesPerScanLine*/ 7680,
/*Bit16u XResolution*/ 1920,
/*Bit16u YResolution*/ 1080,
/*Bit8u  XCharSize*/ 8,
/*Bit8u  YCharSize*/ 16,
/*Bit8u  NumberOfPlanes*/ 1,
/*Bit8u  BitsPerPixel*/ 32,
/*Bit8u  NumberOfBanks*/ 127,
/*Bit8u  MemoryModel*/ VBE_MEMORYMODEL_DIRECT_COLOR,
/*Bit8u  BankSize*/ 0,
/*Bit8u  NumberOfImagePages*/ 1,
/*Bit8u  Reserved_page*/ 0,
/*Bit8u  RedMaskSize*/ 8,
/*Bit8u  RedFieldPosition*/ 16,
/*Bit8u  GreenMaskSize*/ 8,
/*Bit8u  GreenFieldPosition*/ 8,
/*Bit8u  BlueMaskSize*/ 8,
/*Bit8u  BlueFieldPosition*/ 0,
/*Bit8u  RsvdMaskSize*/ 8,
/*Bit8u  RsvdFieldPosition*/ 24,
/*Bit8u  DirectColorModeInfo*/ VBE_DIRECTCOLOR_RESERVED_BITS_AVAILABLE,
/*Bit32u PhysBasePtr*/ VBE_DISPI_LFB_PHYSICAL_ADDRESS,
/*Bit32u OffScreenMemOffset*/ 0,
/*Bit16u OffScreenMemSize*/ 0,
/*Bit16u LinBytesPerScanLine*/ 7680,
/*Bit8u  BnkNumberOfPages*/ 0,
/*Bit8u  LinNumberOfPages*/ 0,
/*Bit8u  LinRedMaskSize*/ 8,
/*Bit8u  LinRedFieldPosition*/ 16,
/*Bit8u  LinGreenMaskSize*/ 8,
/*Bit8u  LinGreenFieldPosition*/ 8,
/*Bit8u  LinBlueMaskSize*/ 8,
/*Bit8u  LinBlueFieldPosition*/ 0,
/*Bit8u  LinRsvdMaskSize*/ 8,
/*Bit8u  LinRsvdFieldPosition*/ 24,
/*Bit32u MaxPixelClock*/ 0,
} },
{ VBE_VESA_MODE_END_OF_LIST,
{ 0,
} },
};
